/*+ Options.cpp
 *
 ******************************************************************************
 *
 *                        Trimble Navigation Limited
 *                           645 North Mary Avenue
 *                              P.O. Box 3642
 *                         Sunnyvale, CA 94088-3642
 *
 ******************************************************************************
 *
 *    Copyright  2005 Trimble Navigation Ltd.
 *    All Rights Reserved
 *
 ******************************************************************************
 *
 * Description:
 *    This file implements the COptions class.
 *            
 * Revision History:
 *    09-22-2005    Mike Priven
 *                  Cleaned up and adapted for outside distribution.
 *
 *    xx-xx-2001    Sean Zhi
 *                  Original
 *
 * Notes:
 *
-*/

/*---------------------------------------------------------------------------*\
 |                         I N C L U D E   F I L E S
\*---------------------------------------------------------------------------*/
#include "stdafx.h"
#include "FlashLoader.h"
#include "FlashLoaderDlg.h"
#include "Options.h"

#ifdef _DEBUG
#define new DEBUG_NEW
#undef THIS_FILE
static char THIS_FILE[] = __FILE__;
#endif


/*---------------------------------------------------------------------------*\
 |                    M E T H O D   D E F I N I T I O N S
\*---------------------------------------------------------------------------*/

/*-----------------------------------------------------------------------------
Function:       <constructor>

Description:    A constructor for this class. Called when a new object of this
                class is created.

Parameters:     pParent - a pointer to the parent window - the window that
                created an object of this class.
                nIDTemplate - ID of the dialog resource associated with the 
                dialog class.

Return Value:   none
-----------------------------------------------------------------------------*/
COptions::COptions(CWnd* pParent /*=NULL*/)
: CDialog(COptions::IDD, pParent)
{
    m_pParentDlg = (CFlashLoaderDlg*)pParent;
    //{{AFX_DATA_INIT(COptions)
    m_int_romtype = 0;
    m_bNoWaitACK = FALSE;
    m_strFwBaseAddr = _T("");
    //}}AFX_DATA_INIT
}

/*-----------------------------------------------------------------------------
Function:       DoDataExchange

Description:    Called by the framework to exchange and validate dialog data.
                Never call this function directly. It is called by the 
                UpdateData() member function

Parameters:     pDX - a pointer to a CDataExchange object

Return Value:   none
-----------------------------------------------------------------------------*/
void COptions::DoDataExchange(CDataExchange* pDX)
{
    CDialog::DoDataExchange(pDX);
    //{{AFX_DATA_MAP(COptions)
    DDX_Radio(pDX, IDC_ROMTYPE_FW, m_int_romtype);
    DDX_Check(pDX, IDC_OBSOLETE_NOWAIT_ACK, m_bNoWaitACK);
    DDX_Text(pDX, IDC_FW_ADDR, m_strFwBaseAddr);
    DDV_MaxChars(pDX, m_strFwBaseAddr, 8);
    //}}AFX_DATA_MAP
}

/*-----------------------------------------------------------------------------
Function:       BEGIN_MESSAGE_MAP (theClass, baseClass)

Description:    Defines a message map for this class. Matches a windows message
                with a callback function. The framework will call this function
                once the message associated with it has been received.

Parameters:     theClass - specifies the name of the class whose message map
                this is
                baseClass - specifies the name of the base class of theClass

Return Value:   none
-----------------------------------------------------------------------------*/
BEGIN_MESSAGE_MAP(COptions, CDialog)
	//{{AFX_MSG_MAP(COptions)
	//}}AFX_MSG_MAP
END_MESSAGE_MAP()

/*-----------------------------------------------------------------------------
Function:       OnInitDialog

Description:    Initialises the main dialog box. This is a standard
                MFC function called automatically after the dialog has been
                created but before it is displayed.

Parameters:     none

Return Value:   specifies whether the application has set the input focus to 
                one of the controls in the dialog box
-----------------------------------------------------------------------------*/
BOOL COptions::OnInitDialog() 
{
    CDialog::OnInitDialog();
    
    m_int_romtype     = (m_pParentDlg->m_int_romType == FW_ROM) ? 0 : 1;
    m_strFwBaseAddr   = m_pParentDlg->m_strFwBaseAddr;
    
    UpdateData (false);
    
    return TRUE;
}

/*-----------------------------------------------------------------------------
Function:       OnOK

Description:    The framework calls this member function when the user clicks 
                the OK button or presses the ENTER key in a modal or 
                modeless dialog box. 

Parameters:     none

Return Value:   none
-----------------------------------------------------------------------------*/
void COptions::OnOK() 
{
    UpdateData(true);
    
    m_pParentDlg->m_int_romType     = (m_int_romtype) ? BOOT_ROM : FW_ROM;
    m_pParentDlg->m_strFwBaseAddr   = m_strFwBaseAddr;
    
    CDialog::OnOK();
}

